@@ -3,8 +3,9 @@ from collections import defaultdict
 from collections.abc import Sequence
 from json import dumps
 from time import time_ns
-from typing import Any, DefaultDict, Dict, List, Optional, Union
+from typing import Any, Optional, Union
 from uuid import UUID
+from warnings import warn
 
 from langchain_core.agents import AgentAction, AgentFinish
 from langchain_core.callbacks import BaseCallbackHandler
@@ -17,9 +18,7 @@ from galileo_core.schemas.shared.workflows.node_type import NodeType
 from promptquality.chain_run_module import chain_run
 from promptquality.constants.run import TagType
 from promptquality.constants.scorers import Scorers
-from promptquality.set_config_module import set_config
 from promptquality.types.chains.row import NodeRow
-from promptquality.types.config import Config
 from promptquality.types.custom_scorer import CustomScorer
 from promptquality.types.customized_scorer import CustomizedChainPollScorer
 from promptquality.types.registered_scorers import RegisteredScorer
@@ -27,15 +26,14 @@ from promptquality.types.run import RunTag, ScorersConfiguration
 from promptquality.utils.logger import logger
 from promptquality.utils.serialization import serialize_to_str
 
-LangchainEmbeddingNames: List[str] = []
-LangchainVectorStoreNames: List[str] = []
+LangchainEmbeddingNames: list[str] = []
+LangchainVectorStoreNames: list[str] = []
 
 # Check if langchain_community is available and import the necessary names.
 if is_dependency_available("langchain_community"):
     from langchain_community.embeddings import __all__ as LangchainEmbeddingNames
     from langchain_community.vectorstores import __all__ as LangchainVectorStoreNames
 
-
 Stringable = (str, int, float)
 EmbeddingRunTagKey = "Embedding Model"
 VectorStoreRunTagKey = "Vector Store"
@@ -46,12 +44,11 @@ class GalileoPromptCallback(BaseCallbackHandler):
         self,
         project_name: Optional[str] = None,
         run_name: Optional[str] = None,
-        scorers: Optional[List[Union[Scorers, CustomizedChainPollScorer, CustomScorer, RegisteredScorer, str]]] = None,
-        generated_scorers: Optional[List[str]] = None,
-        run_tags: Optional[List[RunTag]] = None,
+        scorers: Optional[list[Union[Scorers, CustomizedChainPollScorer, CustomScorer, RegisteredScorer, str]]] = None,
+        generated_scorers: Optional[list[str]] = None,
+        run_tags: Optional[list[RunTag]] = None,
         scorers_config: ScorersConfiguration = ScorersConfiguration(),
         wait: bool = True,
-        config: Optional[Config] = None,
         **kwargs: Any,
     ) -> None:
         """
@@ -73,21 +70,20 @@ class GalileoPromptCallback(BaseCallbackHandler):
         self.generated_scorers = generated_scorers
         self.run_tags = run_tags
         self.wait = wait
-        self.config = config or set_config()
 
         # Row information.
         # Mapping of root of the chain to all children.
-        self.root_child_mapping: DefaultDict = defaultdict(list)
-        self.root_nodes: List[UUID] = list()
+        self.root_child_mapping: defaultdict = defaultdict(list)
+        self.root_nodes: list[UUID] = list()
         # Mapping of parent to children.
-        self.parent_child_mapping: DefaultDict = defaultdict(list)
+        self.parent_child_mapping: defaultdict = defaultdict(list)
         # Mapping of child to parent.
-        self.child_parent_mapping: Dict[UUID, Optional[UUID]] = dict()
+        self.child_parent_mapping: dict[UUID, Optional[UUID]] = dict()
 
-        self.chain_inputs: Dict[UUID, Dict[str, Any]] = dict()
-        self.serializations: Dict[UUID, Dict[str, Any]] = dict()
+        self.chain_inputs: dict[UUID, dict[str, Any]] = dict()
+        self.serializations: dict[UUID, dict[str, Any]] = dict()
 
-        self.rows: Dict[UUID, NodeRow] = dict()
+        self.rows: dict[UUID, NodeRow] = dict()
 
     def set_relationships(self, run_id: UUID, node_type: NodeType, parent_run_id: Optional[UUID] = None) -> None:
         self.child_parent_mapping[run_id] = parent_run_id
@@ -118,10 +114,10 @@ class GalileoPromptCallback(BaseCallbackHandler):
         self,
         run_id: UUID,
         node_name: str,
-        serialized: Optional[Dict[str, Any]],
+        serialized: Optional[dict[str, Any]],
         prompt: Optional[str] = None,
         node_input: str = "",
-        **kwargs: Dict[str, Any],
+        **kwargs: dict[str, Any],
     ) -> None:
         root_id = self.get_root_id(run_id)
         self.rows[run_id].prompt = prompt
@@ -141,7 +137,7 @@ class GalileoPromptCallback(BaseCallbackHandler):
             self.rows[run_id].node_name = node_name
 
     def mark_step_end(
-        self, run_id: UUID, response: Optional[str] = None, node_output: str = "", **kwargs: Dict[str, Any]
+        self, run_id: UUID, response: Optional[str] = None, node_output: str = "", **kwargs: dict[str, Any]
     ) -> None:
         self.rows[run_id].latency = time_ns() - self.rows[run_id].creation_timestamp
         if response:
@@ -152,13 +148,13 @@ class GalileoPromptCallback(BaseCallbackHandler):
 
     def on_retriever_start(
         self,
-        serialized: Optional[Dict[str, Any]],
+        serialized: Optional[dict[str, Any]],
         query: str,
         *,
         run_id: UUID,
         parent_run_id: Optional[UUID] = None,
-        tags: Optional[List[str]] = None,
-        metadata: Optional[Dict[str, Any]] = None,
+        tags: Optional[list[str]] = None,
+        metadata: Optional[dict[str, Any]] = None,
         **kwargs: Any,
     ) -> Any:
         """Run when Retriever starts running."""
@@ -178,36 +174,26 @@ class GalileoPromptCallback(BaseCallbackHandler):
             self.run_tags = run_tags
 
     def on_retriever_end(
-        self,
-        documents: Sequence[Document],
-        *,
-        run_id: UUID,
-        parent_run_id: Optional[UUID] = None,
-        **kwargs: Any,
+        self, documents: Sequence[Document], *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
     ) -> Any:
         """Run when Retriever ends running."""
         self.mark_step_end(run_id, node_output=serialize_to_str(documents), **kwargs)
 
     def on_retriever_error(
-        self,
-        error: BaseException,
-        *,
-        run_id: UUID,
-        parent_run_id: Optional[UUID] = None,
-        **kwargs: Any,
+        self, error: BaseException, *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
     ) -> Any:
         """Run when Retriever errors."""
         del self.rows[run_id]
 
     def on_tool_start(
         self,
-        serialized: Optional[Dict[str, Any]],
+        serialized: Optional[dict[str, Any]],
         input_str: str,
         *,
         run_id: UUID,
         parent_run_id: Optional[UUID] = None,
-        tags: Optional[List[str]] = None,
-        metadata: Optional[Dict[str, Any]] = None,
+        tags: Optional[list[str]] = None,
+        metadata: Optional[dict[str, Any]] = None,
         **kwargs: Any,
     ) -> Any:
         """Run when tool starts running."""
@@ -216,38 +202,18 @@ class GalileoPromptCallback(BaseCallbackHandler):
             run_id, node_name="Tool", serialized=serialized, node_input=serialize_to_str(input_str), **kwargs
         )
 
-    def on_tool_end(
-        self,
-        output: Any,
-        *,
-        run_id: UUID,
-        parent_run_id: Optional[UUID] = None,
-        **kwargs: Any,
-    ) -> Any:
+    def on_tool_end(self, output: Any, *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any) -> Any:
         """Run when tool ends running."""
-        self.mark_step_end(
-            run_id,
-            node_output=serialize_to_str(output),
-            **kwargs,
-        )
+        self.mark_step_end(run_id, node_output=serialize_to_str(output), **kwargs)
 
     def on_tool_error(
-        self,
-        error: BaseException,
-        *,
-        run_id: UUID,
-        parent_run_id: Optional[UUID] = None,
-        **kwargs: Any,
+        self, error: BaseException, *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
     ) -> Any:
         """Run when tool errors."""
         error_text = repr(error)
         if isinstance(error, BaseException):
             error_text += "\n" + "".join(traceback.format_exception(type(error), error, error.__traceback__))
-        self.mark_step_end(
-            run_id,
-            node_output=f"ERROR: {error_text}",
-            **kwargs,
-        )
+        self.mark_step_end(run_id, node_output=f"ERROR: {error_text}", **kwargs)
 
     def on_agent_finish(
         self,
@@ -255,7 +221,7 @@ class GalileoPromptCallback(BaseCallbackHandler):
         *,
         run_id: UUID,
         parent_run_id: Optional[UUID] = None,
-        tags: Optional[List[str]] = None,
+        tags: Optional[list[str]] = None,
         **kwargs: Any,
     ) -> None:
         """
@@ -272,8 +238,8 @@ class GalileoPromptCallback(BaseCallbackHandler):
 
     def on_llm_start(
         self,
-        serialized: Optional[Dict[str, Any]],
-        prompts: List[str],
+        serialized: Optional[dict[str, Any]],
+        prompts: list[str],
         *,
         run_id: UUID,
         parent_run_id: Optional[UUID] = None,
@@ -286,8 +252,8 @@ class GalileoPromptCallback(BaseCallbackHandler):
 
     def on_chat_model_start(
         self,
-        serialized: Optional[Dict[str, Any]],
-        messages: List[List[BaseMessage]],
+        serialized: Optional[dict[str, Any]],
+        messages: list[list[BaseMessage]],
         *,
         run_id: UUID,
         parent_run_id: Optional[UUID] = None,
@@ -341,20 +307,15 @@ class GalileoPromptCallback(BaseCallbackHandler):
             self.rows[run_id].finish_reason = generation.generation_info.get("finish_reason", "")
 
     def on_llm_error(
-        self,
-        error: BaseException,
-        *,
-        run_id: UUID,
-        parent_run_id: Optional[UUID] = None,
-        **kwargs: Any,
+        self, error: BaseException, *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
     ) -> Any:
         """Run when LLM errors."""
         del self.rows[run_id]
 
     def on_chain_start(
         self,
-        serialized: Dict[str, Any],
-        inputs: Union[Dict[str, Any], Any],
+        serialized: dict[str, Any],
+        inputs: Union[dict[str, Any], Any],
         *,
         run_id: UUID,
         parent_run_id: Optional[UUID] = None,
@@ -384,7 +345,7 @@ class GalileoPromptCallback(BaseCallbackHandler):
         self.set_relationships(run_id, node_type=node_type, parent_run_id=parent_run_id)
 
         if isinstance(inputs, Stringable):
-            node_input: Union[Dict, List] = {"input": inputs}
+            node_input: Union[dict, list] = {"input": inputs}
         elif isinstance(inputs, BaseMessage):
             node_input = message_to_dict(inputs)
         elif isinstance(inputs, dict):
@@ -408,17 +369,19 @@ class GalileoPromptCallback(BaseCallbackHandler):
             logger.warning(f"Unsupported input type {type(inputs)} for {run_id=}, {parent_run_id=}. Skipping...")
             node_input = dict()
         self.chain_inputs[run_id] = (
-            node_input if isinstance(node_input, Dict) else {str(i): val for i, val in enumerate(node_input)}
+            node_input if isinstance(node_input, dict) else {str(i): val for i, val in enumerate(node_input)}
         )
         self.mark_step_start(
             run_id, node_name=node_name, serialized=serialized, node_input=serialize_to_str(inputs), **kwargs
         )
 
     def on_chain_end(
-        self, outputs: Union[str, Dict[str, Any]], *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
+        self, outputs: Union[str, dict[str, Any]], *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
     ) -> Any:
         """Run when chain ends running."""
-        self.rows[run_id].finish_reason = "chain_end"
+        # If the node was never started, don't track it.
+        if run_id not in self.rows:
+            return
         response: Optional[str] = None
 
         if isinstance(outputs, dict):
@@ -427,34 +390,44 @@ class GalileoPromptCallback(BaseCallbackHandler):
             # The 'output' key is present on agent chains
             response = str(outputs.get("text", "")) or str(outputs.get("output", ""))
 
-        self.mark_step_end(
-            run_id,
-            response=response,
-            node_output=serialize_to_str(outputs),
-            **kwargs,
-        )
+        self.mark_step_end(run_id, response=response, node_output=serialize_to_str(outputs), **kwargs)
 
     def on_chain_error(
         self, error: BaseException, *, run_id: UUID, parent_run_id: Optional[UUID] = None, **kwargs: Any
     ) -> Any:
         """Run when chain errors."""
 
-    def add_targets(self, targets: List[str]) -> None:
+    def add_targets(self, targets: list[str]) -> None:
         """
         targets: List[str]:
             A list of target outputs. The list should be the length of the number of chain invokations.
             Targets will be mapped to chain root nodes.
         """
+        warn("add_targets is deprecated, use add_expected_output instead", DeprecationWarning, stacklevel=2)
         if len(targets) != len(self.root_nodes):
             raise ValueError(
                 f"Got {len(targets)} targets but expected {len(self.root_nodes)}"
                 "The number of targets must match the number of chain invokations."
             )
-        for root_id, target in zip(self.root_nodes, targets):
+        return self.add_expected_outputs(targets)
+
+    def add_expected_outputs(self, expected_outputs: list[str]) -> None:
+        """
+        expected_outputs: List[str]:
+            A list of expected outputs. The list should be the length of the number of chain invokations.
+            Expected outputs will be mapped to chain root nodes.
+        """
+        # "targets" parameter was renamed to "expected_outputs" for user clarity.
+        if len(expected_outputs) != len(self.root_nodes):
+            raise ValueError(
+                f"Got {len(expected_outputs)} expected_outputs but expected {len(self.root_nodes)}"
+                "The number of expected_outputs must match the number of chain invokations."
+            )
+        for root_id, target in zip(self.root_nodes, expected_outputs):
             self.rows[root_id].target = target
 
     def finish(self) -> None:
-        rows_to_log: List[NodeRow] = list()
+        rows_to_log: list[NodeRow] = list()
         # Exclude chains that don't have children.
         for root_id in self.root_nodes:
             for node_id in self.root_child_mapping[root_id]:
@@ -475,5 +448,4 @@ class GalileoPromptCallback(BaseCallbackHandler):
             scorers_config=self.scorers_config,
             run_tags=self.run_tags,
             wait=self.wait,
-            config=self.config,
         )
