@@ -12,12 +12,21 @@ class Scorers(str, Enum):
     chunk_attribution_utilization_plus = "chunk_attribution_utilization_gpt"
     pii = "pii"
     prompt_injection = "prompt_injection"
+    prompt_injection_plus = "prompt_injection_gpt"
     prompt_perplexity = "prompt_perplexity"
+    input_sexist = "input_sexist"
+    input_sexist_plus = "input_sexist_gpt"
     sexist = "sexist"
+    sexist_plus = "sexist_gpt"
     tone = "tone"
+    # TODO why no input toxicity existing here currently?
+    input_toxicity = "input_toxicity"
+    input_toxicity_plus = "input_toxicity_gpt"
     toxicity = "toxicity"
+    toxicity_plus = "toxicity_gpt"
     instruction_adherence_plus = "instruction_adherence"
     ground_truth_adherence_plus = "ground_truth_adherence"
     tool_errors_plus = "tool_error_rate"
     tool_selection_quality_plus = "tool_selection_quality"
     action_advancement_plus = "agentic_workflow_success"
+    action_completion_plus = "agentic_session_success"
