@@ -1,4 +1,4 @@
-from typing import List, Optional, Union
+from typing import Optional, Union
 from uuid import UUID
 
 from pydantic import UUID4
@@ -7,13 +7,8 @@ from galileo_core.schemas.shared.scorers.base_configs import GeneratedScorerConf
 from promptquality.constants.prompt_optimization import PromptOptimizationDefaults
 from promptquality.constants.run import RunDefaults
 from promptquality.get_rows_module import get_rows
-from promptquality.set_config_module import set_config
-from promptquality.types.chains.row import (
-    ChainIngestRequest,
-    ChainIngestResponse,
-    NodeRow,
-)
-from promptquality.types.config import Config
+from promptquality.types.chains.row import ChainIngestRequest, ChainIngestResponse, NodeRow
+from promptquality.types.config import PromptQualityConfig
 from promptquality.types.custom_scorer import CustomScorer
 from promptquality.types.customized_scorer import CustomizedChainPollScorer
 from promptquality.types.prompt_optimization import PromptOptimizationConfiguration
@@ -45,34 +40,32 @@ from promptquality.utils.dataset import DatasetType
 from promptquality.utils.logger import logger
 
 
-def create_project(project_name: Optional[str] = None, config: Optional[Config] = None) -> ProjectResponse:
-    config = config or set_config()
+def create_project(project_name: Optional[str] = None) -> ProjectResponse:
+    config = PromptQualityConfig.get()
     project_request = CreateProjectRequest(name=project_name)
-    existing_project = get_project_from_name(project_request.name, raise_if_missing=False, config=config)
+    existing_project = get_project_from_name(project_request.name, raise_if_missing=False)
     if existing_project:
         logger.info(f"Project {project_request.name} already exists, using it.")
         project_response = existing_project
     else:
         logger.debug(f"Creating project {project_request.name}...")
-        response_dict = config.api_client.create_project(project_request)
+        response_dict = config.pq_api_client.create_project(project_request)
         project_response = ProjectResponse.model_validate(response_dict)
         logger.debug(f"Created project with name {project_response.name}, ID {project_response.id}.")
     config.merge_project(project_response)
     return project_response
 
 
-def get_project(project_id: UUID4, config: Optional[Config] = None) -> ProjectResponse:
-    config = config or set_config()
-    response_dict = config.api_client.get_project(project_id)
+def get_project(project_id: UUID4) -> ProjectResponse:
+    config = PromptQualityConfig.get()
+    response_dict = config.pq_api_client.get_project(project_id)
     project = ProjectResponse.model_validate(response_dict)
     logger.debug(f"Got project with name {project.name}, ID {project.id}.")
     config.merge_project(project)
     return project
 
 
-def get_project_from_name(
-    project_name: str, raise_if_missing: bool = True, config: Optional[Config] = None
-) -> Optional[ProjectResponse]:
+def get_project_from_name(project_name: str, raise_if_missing: bool = True) -> Optional[ProjectResponse]:
     """
     Get a project by name.
 
@@ -82,17 +75,16 @@ def get_project_from_name(
         Name of the project.
     raise_if_missing : bool
         Whether to raise an error if the project is missing.
-    config : Optional[Config]
-        Config object.
+
     Returns
     -------
     Optional[ProjectResponse]
         Project object.
     """
-    config = config or set_config()
+    config = PromptQualityConfig.get()
     projects = [
         ProjectResponse.model_validate(proj)
-        for proj in config.api_client.get_project_by_name(project_name=project_name)
+        for proj in config.pq_api_client.get_project_by_name(project_name=project_name)
     ]
     if raise_if_missing and len(projects) == 0:
         raise ValueError(f"Project {project_name} does not exist.")
@@ -106,10 +98,7 @@ def get_project_from_name(
 
 
 def create_template(
-    template: str,
-    project_id: Optional[UUID4] = None,
-    template_name: Optional[str] = None,
-    config: Optional[Config] = None,
+    template: str, project_id: Optional[UUID4] = None, template_name: Optional[str] = None
 ) -> BaseTemplateResponse:
     """
     Create a template in the project.
@@ -142,12 +131,12 @@ def create_template(
     ValueError
         If the project ID is not set in config.
     """
-    config = config or set_config()
+    config = PromptQualityConfig.get()
     project_id = project_id or config.current_project_id
     if not project_id:
         raise ValueError("Project ID must be provided or set in config to create a template.")
     template_request = CreateTemplateRequest(template=template, project_id=project_id, name=template_name)
-    existing_templates = {template.name: template for template in get_templates(project_id, config)}
+    existing_templates = {template.name: template for template in get_templates(project_id)}
     if template_request.name in existing_templates:
         existing_template_response = existing_templates[template_request.name]
         logger.debug(
@@ -163,17 +152,12 @@ def create_template(
         else:
             logger.debug("Creating template version for template {existing_template_response.id}...")
             template_version = create_template_version(
-                template_request.template,
-                template_id=existing_template_response.id,
-                project_id=project_id,
-                config=config,
+                template_request.template, template_id=existing_template_response.id, project_id=project_id
             )
-        template_response = select_template_version(
-            template_version.version, project_id, existing_template_response.id, config
-        )
+        template_response = select_template_version(template_version.version, project_id, existing_template_response.id)
     else:
         logger.debug(f"Creating template {template_request.name}...")
-        response_dict = config.api_client.create_template(template_request)
+        response_dict = config.pq_api_client.create_template(template_request)
         template_response = BaseTemplateResponse.model_validate(response_dict)
     config.merge_template(template_response)
     logger.debug(f"Created template with name {template_response.name}, ID {template_response.id}.")
@@ -181,11 +165,9 @@ def create_template(
 
 
 def get_template_from_id(
-    project_id: Optional[UUID4] = None,
-    template_id: Optional[UUID4] = None,
-    config: Optional[Config] = None,
+    project_id: Optional[UUID4] = None, template_id: Optional[UUID4] = None
 ) -> BaseTemplateResponse:
-    config = config or set_config()
+    config = PromptQualityConfig.get()
     project_id = project_id or config.current_project_id
     template_id = template_id or config.current_template_id
     if not project_id:
@@ -194,47 +176,42 @@ def get_template_from_id(
         raise ValueError("Template ID must be provided or set in config to get the template.")
     logger.debug(f"Getting template for {project_id=} and {template_id=}...")
     return BaseTemplateResponse.model_validate(
-        config.api_client.get_template(project_id=project_id, template_id=template_id)
+        config.pq_api_client.get_template(project_id=project_id, template_id=template_id)
     )
 
 
 def get_template_version_from_name(
-    template_version: TemplateVersion,
-    project_id: Optional[UUID4] = None,
-    config: Optional[Config] = None,
+    template_version: TemplateVersion, project_id: Optional[UUID4] = None
 ) -> CreateTemplateVersionResponse:
-    config = config or set_config()
+    config = PromptQualityConfig.get()
     project_id = project_id or config.current_project_id
     if not project_id:
         raise ValueError("Project ID must be provided or set in config to get the template.")
     logger.debug(
         f"Getting template version {template_version.version} for project {project_id} and template {template_version.name}..."
     )
-    template_version_response = config.api_client.get_template_version_by_name(
+    template_version_response = config.pq_api_client.get_template_version_by_name(
         project_id, template_version.name, template_version.version
     )
     return CreateTemplateVersionResponse.model_validate(template_version_response)
 
 
-def get_templates(project_id: Optional[UUID4] = None, config: Optional[Config] = None) -> List[BaseTemplateResponse]:
-    config = config or set_config()
+def get_templates(project_id: Optional[UUID4] = None) -> list[BaseTemplateResponse]:
+    config = PromptQualityConfig.get()
     project_id = project_id or config.current_project_id
     if not project_id:
         raise ValueError("Project ID must be provided or set in config to get the templates.")
     logger.debug(f"Getting all templates for {project_id=}...")
     return [
         BaseTemplateResponse.model_validate(template)
-        for template in config.api_client.get_templates(project_id=project_id)
+        for template in config.pq_api_client.get_templates(project_id=project_id)
     ]
 
 
 def select_template_version(
-    version: int,
-    project_id: Optional[UUID4] = None,
-    template_id: Optional[UUID4] = None,
-    config: Optional[Config] = None,
+    version: int, project_id: Optional[UUID4] = None, template_id: Optional[UUID4] = None
 ) -> BaseTemplateResponse:
-    config = config or set_config()
+    config = PromptQualityConfig.get()
     project_id = project_id or config.current_project_id
     template_id = template_id or config.current_template_id
     if not project_id:
@@ -249,7 +226,7 @@ def select_template_version(
         f"Selecting template version {template_version_request.version} for "
         f"template ID {template_version_request.template_id}..."
     )
-    response_dict = config.api_client.put_template_version_selection(template_version_request)
+    response_dict = config.pq_api_client.put_template_version_selection(template_version_request)
     template_response = BaseTemplateResponse.model_validate(response_dict)
     config.merge_template(template_response)
     logger.debug(
@@ -265,7 +242,6 @@ def create_template_version(
     project_id: Optional[UUID4] = None,
     template_id: Optional[UUID4] = None,
     version: Optional[int] = None,
-    config: Optional[Config] = None,
 ) -> CreateTemplateVersionResponse:
     """
     Create a template version for the current template ID in config.
@@ -296,7 +272,7 @@ def create_template_version(
     ValueError
         If the project ID is not set in config.
     """
-    config = config or set_config()
+    config = PromptQualityConfig.get()
     project_id = project_id or config.current_project_id
     template_id = template_id or config.current_template_id
     if not project_id:
@@ -304,37 +280,27 @@ def create_template_version(
     if not template_id:
         raise ValueError("Template ID must be provided or set in config before creating template version.")
     version_request = CreateTemplateVersionRequest(
-        template=template,
-        version=version,
-        project_id=project_id,
-        template_id=template_id,
+        template=template, version=version, project_id=project_id, template_id=template_id
     )
     logger.debug("Creating template version for template ID {version_request.template_id}...")
-    response_dict = config.api_client.create_template_version(version_request)
+    response_dict = config.pq_api_client.create_template_version(version_request)
     version_response = CreateTemplateVersionResponse.model_validate(response_dict)
     config.merge_template_version(version_response)
     logger.debug(f"Created template version with ID {version_response.id}, version {version_response.version}.")
     return version_response
 
 
-def upload_dataset(
-    dataset: Union[UUID4, DatasetType],
-    project_id: UUID4,
-    template_version_id: UUID4,
-    config: Optional[Config] = None,
-) -> UUID4:
-    config = config or set_config()
+def upload_dataset(dataset: Union[UUID4, DatasetType], project_id: UUID4, template_version_id: UUID4) -> UUID4:
+    config = PromptQualityConfig.get()
     if isinstance(dataset, UUID):
         logger.debug("UUID passed for dataset.")
         return dataset
 
     dataset_request = UploadDatasetRequest(
-        project_id=project_id,
-        prompt_template_version_id=template_version_id,
-        file_path=dataset,
+        project_id=project_id, prompt_template_version_id=template_version_id, file_path=dataset
     )
     logger.debug(f"Uploading dataset {dataset_request.file_path}...")
-    response_dict = config.api_client.upload_dataset(dataset_request)
+    response_dict = config.pq_api_client.upload_dataset(dataset_request)
     dataset_response = Dataset.model_validate(response_dict)
     config.merge_dataset(dataset_response)
     logger.debug(f"Uploaded dataset with ID {dataset_response.id}.")
@@ -345,25 +311,20 @@ def create_run(
     project_id: UUID4,
     run_name: Optional[str] = None,
     task_type: int = RunDefaults.prompt_evaluation_task_type,
-    run_tags: Optional[List[RunTag]] = None,
-    config: Optional[Config] = None,
+    run_tags: Optional[list[RunTag]] = None,
 ) -> UUID4:
-    config = config or set_config()
+    config = PromptQualityConfig.get()
     run_tags = run_tags or list()
     run_request = CreateRunRequest(name=run_name, project_id=project_id, task_type=task_type, run_tags=run_tags)
     logger.debug(f"Creating run {run_request.name}...")
-    response_dict = config.api_client.create_run(run_request)
+    response_dict = config.pq_api_client.create_run(run_request)
     run_response = RunResponse.model_validate(response_dict)
     config.merge_run(run_response)
     logger.debug(f"Created run with name {run_request.name}, ID {run_response.id}.")
     return run_response.id
 
 
-def get_run_from_name(
-    run_name: str,
-    project_id: Optional[UUID4] = None,
-    config: Optional[Config] = None,
-) -> RunResponse:
+def get_run_from_name(run_name: str, project_id: Optional[UUID4] = None) -> RunResponse:
     """
     Retrieve a run by name.
 
@@ -380,13 +341,13 @@ def get_run_from_name(
     RunResponse
         Run object.
     """
-    config = config or set_config()
+    config = PromptQualityConfig.get()
     project_id = project_id or config.current_project_id
     if not project_id:
         raise ValueError("Project ID must be provided or set in config to get the run.")
     runs = [
         RunResponse.model_validate(run)
-        for run in config.api_client.get_run_by_name(project_id=project_id, name=run_name)
+        for run in config.pq_api_client.get_run_by_name(project_id=project_id, name=run_name)
     ]
     if runs:
         run_response = runs[0]
@@ -398,10 +359,7 @@ def get_run_from_name(
 
 
 def get_run_settings(
-    run_name: Optional[str] = None,
-    run_id: Optional[UUID4] = None,
-    project_id: Optional[UUID4] = None,
-    config: Optional[Config] = None,
+    run_name: Optional[str] = None, run_id: Optional[UUID4] = None, project_id: Optional[UUID4] = None
 ) -> Optional[Settings]:
     """
     Retrieves the prompt settings for a given run. Can pass either run_name or run_id. If both are passed, run_id will
@@ -422,19 +380,19 @@ def get_run_settings(
     Optional[Settings]
         Prompt settings for the run.
     """
-    config = config or set_config()
+    config = PromptQualityConfig.get()
     project_id = project_id or config.current_project_id
     if not project_id:
         raise ValueError("Project ID must be provided or set in config to get the run.")
     if run_id is not None:
         pass
     elif run_name is not None:
-        run_id = get_run_from_name(run_name, project_id, config).id
+        run_id = get_run_from_name(run_name, project_id).id
     else:
         run_id = config.current_run_id
     if not run_id:
         raise ValueError("Run ID or run name must be provided or set in config to get the run settings.")
-    run = PromptRunResponse.model_validate(config.api_client.get_prompt_run(project_id, run_id))
+    run = PromptRunResponse.model_validate(config.pq_api_client.get_prompt_run(project_id, run_id))
     return run.prompt_settings
 
 
@@ -445,12 +403,11 @@ def create_job(
     template_version_id: Optional[UUID4] = None,
     settings: Optional[Settings] = None,
     scorers_config: ScorersConfiguration = ScorersConfiguration(),
-    registered_scorers: Optional[List[RegisteredScorer]] = None,
-    generated_scorers: Optional[List[str]] = None,
-    customized_scorers: Optional[List[CustomizedChainPollScorer]] = None,
-    config: Optional[Config] = None,
+    registered_scorers: Optional[list[RegisteredScorer]] = None,
+    generated_scorers: Optional[list[str]] = None,
+    customized_scorers: Optional[list[CustomizedChainPollScorer]] = None,
 ) -> UUID4:
-    config = config or set_config()
+    config = PromptQualityConfig.get()
     project_id = project_id or config.current_project_id
     run_id = run_id or config.current_run_id
     template_version_id = template_version_id or config.current_template_version_id
@@ -472,7 +429,7 @@ def create_job(
         prompt_template_version_id=template_version_id,
     )
     logger.debug("Creating job...")
-    response_dict = config.api_client.create_job(job_request)
+    response_dict = config.pq_api_client.create_job(job_request)
     job_response = CreateJobResponse.model_validate(response_dict)
     config.merge_job(job_response)
     logger.debug(f"Created job with ID {job_response.job_id}.")
@@ -484,7 +441,6 @@ def create_prompt_optimization_job(
     project_id: UUID4,
     run_id: UUID4,
     train_dataset_id: UUID4,
-    config: Config,
 ) -> UUID4:
     """
     Kicks off a prompt optimization job in Runners.
@@ -512,21 +468,22 @@ def create_prompt_optimization_job(
         job_name=PromptOptimizationDefaults.prompt_optimization_job_name,
         prompt_optimization_configuration=prompt_optimization_configuration,
     )
+    config = PromptQualityConfig.get()
     logger.debug("Creating job...")
-    response_dict = config.api_client.create_job(job_request)
+    response_dict = config.pq_api_client.create_job(job_request)
     job_response = CreateJobResponse.model_validate(response_dict)
     config.merge_job(job_response)
     logger.debug(f"Created job with ID {job_response.job_id}.")
     return job_response.job_id
 
 
-def get_job_status(job_id: Optional[UUID4] = None, config: Optional[Config] = None) -> GetJobStatusResponse:
-    config = config or set_config()
+def get_job_status(job_id: Optional[UUID4] = None) -> GetJobStatusResponse:
+    config = PromptQualityConfig.get()
     logger.debug(f"Getting job status for job {job_id}...")
     job_id = job_id or config.current_job_id
     if not job_id:
         raise ValueError("job_id must be provided")
-    response_dict = config.api_client.get_job_status(job_id)
+    response_dict = config.pq_api_client.get_job_status(job_id)
     job_status_response = GetJobStatusResponse.model_validate(response_dict)
     logger.debug(
         f"Got job status for job {job_id}, status is "
@@ -541,35 +498,33 @@ def upload_custom_metrics(
     project_id: Optional[UUID4] = None,
     run_id: Optional[UUID4] = None,
     task_type: Optional[int] = None,
-    config: Optional[Config] = None,
 ) -> UserSubmittedMetricsResponse:
-    config = config or set_config()
+    config = PromptQualityConfig.get()
     project_id = project_id or config.current_project_id
     run_id = run_id or config.current_run_id
     if not project_id:
         raise ValueError("Project ID must be provided or set in config before uploading custom metrics.")
     if not run_id:
         raise ValueError("Run ID must be provided or set in config before uploading custom metrics.")
-    prompt_rows = get_rows(project_id, run_id, task_type, config=config)
+    prompt_rows = get_rows(project_id, run_id, task_type)
     scores = UserSubmittedMetrics.from_scorer(custom_scorer, prompt_rows)
     logger.debug(f"Uploading custom scores for {custom_scorer.name}...")
-    response_dict = config.api_client.put_user_metrics(scores, project_id, run_id)
+    response_dict = config.pq_api_client.put_user_metrics(scores, project_id, run_id)
     upload_metrics_response = UserSubmittedMetricsResponse.model_validate(response_dict)
     logger.debug(f"Uploaded custom scores for {custom_scorer.name} with job ID {upload_metrics_response.job_id}.")
     return upload_metrics_response
 
 
 def ingest_chain_rows(
-    rows: List[NodeRow],
+    rows: list[NodeRow],
     project_id: Optional[UUID4] = None,
     run_id: Optional[UUID4] = None,
     scorers_config: ScorersConfiguration = ScorersConfiguration(),
-    registered_scorers: Optional[List[RegisteredScorer]] = None,
-    generated_scorers: Optional[List[GeneratedScorerConfig]] = None,
-    customized_scorers: Optional[List[CustomizedChainPollScorer]] = None,
-    config: Optional[Config] = None,
+    registered_scorers: Optional[list[RegisteredScorer]] = None,
+    generated_scorers: Optional[list[GeneratedScorerConfig]] = None,
+    customized_scorers: Optional[list[CustomizedChainPollScorer]] = None,
 ) -> ChainIngestResponse:
-    config = config or set_config()
+    config = PromptQualityConfig.get()
     project_id = project_id or config.current_project_id
     run_id = run_id or config.current_run_id
     if not project_id:
@@ -584,29 +539,10 @@ def ingest_chain_rows(
         prompt_customized_scorers_configuration=customized_scorers,
     )
     logger.debug(f"Ingesting chain rows for project {project_id}, run {run_id}...")
-    response_dict = config.api_client.ingest_chain_rows(ingest_request, project_id, run_id)
+    response_dict = config.pq_api_client.ingest_chain_rows(ingest_request, project_id, run_id)
     chain_ingest_response = ChainIngestResponse.model_validate(response_dict)
     config.merge_job(chain_ingest_response)
     logger.debug(
         f"Ingested chain rows for project {project_id}, run {run_id}, with {chain_ingest_response.num_rows} rows."
     )
     return chain_ingest_response
-
-
-def get_run_scorer_jobs(
-    project_id: Optional[UUID4] = None,
-    run_id: Optional[UUID4] = None,
-    config: Optional[Config] = None,
-) -> List[GetJobStatusResponse]:
-    config = config or set_config()
-    project_id = project_id or config.current_project_id
-    run_id = run_id or config.current_run_id
-    if not project_id:
-        raise ValueError("Project ID must be provided or set in config before getting run scorer jobs.")
-    if not run_id:
-        raise ValueError("Run ID must be provided or set in config before getting run scorer jobs.")
-    logger.debug(f"Getting run scorer jobs for project {project_id}, run {run_id}...")
-    response_dict = config.api_client.get_run_scorer_jobs(project_id, run_id)
-    jobs = [GetJobStatusResponse.model_validate(job) for job in response_dict]
-    logger.debug(f"Got {len(jobs)} run scorer jobs for project {project_id}, run {run_id}.")
-    return [job for job in jobs if job.job_name == RunDefaults.prompt_scorer_job_name]
