@@ -1,10 +1,11 @@
+from collections.abc import Iterable
 from itertools import product
-from typing import Callable, Dict, Iterable
+from typing import Callable
 
 from tqdm.auto import tqdm
 
 
-def sweep(fn: Callable, params: Dict[str, Iterable]) -> None:
+def sweep(fn: Callable, params: dict[str, Iterable]) -> None:
     """
     Run a sweep of a function over various settings.
 
