@@ -1,4 +1,4 @@
-from typing import Callable, Dict, List, Optional, Union
+from typing import Callable, Optional, Union
 
 from pydantic import BaseModel, ConfigDict, Field, field_validator
 
@@ -11,7 +11,7 @@ CustomMetricType = Union[float, int, bool, str, None]
 class CustomScorer(BaseModel):
     name: str
     scorer_fn: Callable[[PromptRow], CustomMetricType] = Field(validation_alias="executor")
-    aggregator_fn: Optional[Callable[[List[CustomMetricType], List[int]], Dict[str, CustomMetricType]]] = Field(
+    aggregator_fn: Optional[Callable[[list[CustomMetricType], list[int]], dict[str, CustomMetricType]]] = Field(
         default=None, validation_alias="aggregator"
     )
 
