@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import Optional
 
 from pydantic import BaseModel, ConfigDict, Field
 
@@ -15,11 +15,11 @@ class EvaluateSample(BaseModel):
     output: str
     target: Optional[str] = None
     cost: Optional[float] = None
-    children: List["EvaluateSample"] = Field(default_factory=list)
+    children: list["EvaluateSample"] = Field(default_factory=list)
     model_config = ConfigDict(extra="allow")
 
 
 class EvaluateSamples(BaseModel):
     """A collection of evaluate samples."""
 
-    samples: List[EvaluateSample] = Field(default_factory=list)
+    samples: list[EvaluateSample] = Field(default_factory=list)
