@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import Optional
 
 from pydantic import UUID4, BaseModel, ConfigDict, Field
 
@@ -10,10 +10,10 @@ class RegisteredScorer(BaseModel):
     id: UUID4 = Field(alias="registered_scorer_id")
     name: str = Field(alias="metric_name")
     score_type: Optional[str] = None
-    scoreable_node_types: Optional[List[str]] = None
+    scoreable_node_types: Optional[list[str]] = None
 
     model_config = ConfigDict(populate_by_name=True)
 
 
 class ListRegisteredScorers(PaginationResponseMixin):
-    scorers: List[RegisteredScorer]
+    scorers: list[RegisteredScorer]
