@@ -1,7 +1,6 @@
-from enum import Enum
 from io import BufferedReader
 from pathlib import Path
-from typing import Dict, List, Optional
+from typing import Annotated, Optional
 
 from pydantic import (
     UUID4,
@@ -9,16 +8,12 @@ from pydantic import (
     BaseModel,
     ConfigDict,
     Field,
-    SecretStr,
     StringConstraints,
-    field_serializer,
     field_validator,
     model_validator,
 )
-from typing_extensions import Annotated
 
 from promptquality.constants.dataset_format import DatasetFormat
-from promptquality.constants.integrations import IntegrationName
 from promptquality.constants.job import JobStatus
 from promptquality.constants.run import RunDefaults, TagType
 from promptquality.constants.scorers import Scorers
@@ -81,7 +76,7 @@ class BaseTemplateResponse(BaseModel):
     template: str
     selected_version: CreateTemplateVersionResponse
     selected_version_id: UUID4
-    all_versions: List[CreateTemplateVersionResponse] = Field(default_factory=list)
+    all_versions: list[CreateTemplateVersionResponse] = Field(default_factory=list)
 
 
 class BaseDatasetRequest(BaseModel):
@@ -89,13 +84,13 @@ class BaseDatasetRequest(BaseModel):
     file_path: Path = Field(exclude=True)
 
     @model_validator(mode="before")
-    def dataset_to_path(cls, values: Dict) -> Dict:
+    def dataset_to_path(cls, values: dict) -> dict:
         if "file_path" in values:
             values["file_path"], values["format"] = parse_dataset(values["file_path"])
         return values
 
     @property
-    def files(self) -> Dict[str, BufferedReader]:
+    def files(self) -> dict[str, BufferedReader]:
         return dict(file=self.file_path.open("rb"))
 
 
@@ -105,11 +100,8 @@ class UploadDatasetRequest(BaseDatasetRequest):
     file_path: Path = Field(exclude=True)
 
     @property
-    def params(self) -> Dict[str, str]:
-        return dict(
-            prompt_template_version_id=str(self.prompt_template_version_id),
-            format=self.format.value,
-        )
+    def params(self) -> dict[str, str]:
+        return dict(prompt_template_version_id=str(self.prompt_template_version_id), format=self.format.value)
 
 
 class Dataset(BaseModel):
@@ -128,7 +120,7 @@ class CreateRunRequest(BaseModel):
     name: str
     project_id: UUID4
     task_type: int = RunDefaults.prompt_evaluation_task_type
-    run_tags: List[RunTag] = Field(default_factory=list)
+    run_tags: list[RunTag] = Field(default_factory=list)
 
     @field_validator("name", mode="before")
     def generate_name(cls, value: Optional[str]) -> str:
@@ -153,7 +145,7 @@ class PromptRunResponse(RunResponse):
 
 class ProjectResponse(CreateProjectRequest):
     id: UUID4
-    runs: List[RunResponse] = Field(default_factory=list)
+    runs: list[RunResponse] = Field(default_factory=list)
 
 
 class ScorerSettings(BaseModel):
@@ -181,11 +173,20 @@ class ScorersConfiguration(BaseModel):
     tool_selection_quality: bool = False
     pii: bool = False
     prompt_injection: bool = False
+    prompt_injection_gpt: bool = False
     prompt_perplexity: bool = False
+    input_sexist: bool = False
+    input_sexist_gpt: bool = False
     sexist: bool = False
+    sexist_gpt: bool = False
     tone: bool = False
     tool_error_rate: bool = False
+    # TODO why no input toxicity existing here currently?
+    input_toxicity: bool = False
+    input_toxicity_gpt: bool = False
     toxicity: bool = False
+    toxicity_gpt: bool = False
+    agentic_session_success: bool = False
     agentic_workflow_success: bool = False
 
     @model_validator(mode="after")
@@ -198,15 +199,25 @@ class ScorersConfiguration(BaseModel):
             source = "attribution/utilization"
         elif self.completeness_gpt and self.completeness_nli:
             source = "completeness"
+        elif self.input_sexist_gpt and self.input_sexist:
+            source = "input sexist"
+        elif self.sexist_gpt and self.sexist:
+            source = "sexist"
+        elif self.input_toxicity_gpt and self.input_toxicity:
+            source = "input toxicity"
+        elif self.toxicity_gpt and self.toxicity:
+            source = "toxicity"
+        elif self.prompt_injection_gpt and self.prompt_injection:
+            source = "prompt injection"
         if source:
             raise ValueError(f"Cannot use Luna {source} with Plus {source}")
         return self
 
     @classmethod
-    def from_scorers(cls, scorers: List[Scorers]) -> "ScorersConfiguration":
+    def from_scorers(cls, scorers: list[Scorers]) -> "ScorersConfiguration":
         return cls(**{scorer.value: True for scorer in scorers})
 
-    def merge_scorers(self, scorers: List[Scorers]) -> "ScorersConfiguration":
+    def merge_scorers(self, scorers: list[Scorers]) -> "ScorersConfiguration":
         return self.model_copy(update={scorer.value: True for scorer in scorers})
 
 
@@ -218,9 +229,9 @@ class CreateJobRequest(BaseModel):
     prompt_settings: Optional[Settings] = None
     prompt_scorers_configuration: Optional[ScorersConfiguration] = None
     prompt_scorer_settings: Optional[ScorerSettings] = None
-    prompt_registered_scorers_configuration: Optional[List[RegisteredScorer]] = None
-    prompt_generated_scorers_configuration: Optional[List[str]] = None
-    prompt_customized_scorers_configuration: Optional[List[CustomizedChainPollScorer]] = None
+    prompt_registered_scorers_configuration: Optional[list[RegisteredScorer]] = None
+    prompt_generated_scorers_configuration: Optional[list[str]] = None
+    prompt_customized_scorers_configuration: Optional[list[CustomizedChainPollScorer]] = None
     job_name: str = RunDefaults.prompt_run_job_name
     task_type: Optional[int] = RunDefaults.prompt_evaluation_task_type
     prompt_optimization_configuration: Optional[PromptOptimizationConfiguration] = None
@@ -276,39 +287,6 @@ class AzureModelDeployment(BaseModel):
     )
 
 
-class AzureAuthenticationType(str, Enum):
-    api_key = "api_key"
-    client_secret = "client_secret"
-    username_password = "username_password"
-
-
-class CreateIntegrationRequest(BaseModel):
-    api_key: SecretStr = Field(serialization_alias="token")
-    name: str = Field(exclude=True)
-    organization_id: Optional[str] = None
-    authentication_type: Optional[AzureAuthenticationType] = None
-    authentication_scope: Optional[str] = None
-    available_deployments: Optional[List[AzureModelDeployment]] = Field(
-        default=None,
-        description="The available deployments for this integration. If provided, we will not try to get this list from Azure.",
-    )
-    endpoint: Optional[str] = None
-    headers: Optional[Dict[str, str]] = None
-    proxy: Optional[bool] = None
-    api_version: Optional[str] = None
-    azure_deployment: Optional[str] = None
-
-    @field_validator("name", mode="before")
-    def validate_name(cls, value: Optional[str]) -> str:
-        if value not in vars(IntegrationName):
-            raise ValueError(f"Integration name must be one of {vars(IntegrationName)}.")
-        return value
-
-    @field_serializer("api_key", when_used="always")
-    def serialize_api_key(self, value: SecretStr) -> str:
-        return value.get_secret_value()
-
-
 class SelectTemplateVersionRequest(BaseModel):
     project_id: UUID4
     template_id: UUID4
