@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Optional
+from typing import Any, Optional
 
 from pydantic import BaseModel, ConfigDict
 
@@ -9,7 +9,7 @@ class Settings(BaseModel):
     model_alias: Optional[str] = None
     temperature: Optional[float] = None
     max_tokens: Optional[int] = None
-    stop_sequences: Optional[List[str]] = None
+    stop_sequences: Optional[list[str]] = None
 
     top_p: Optional[float] = None
     frequency_penalty: Optional[float] = None
@@ -17,8 +17,8 @@ class Settings(BaseModel):
 
     # Internal settings.
     n: Optional[int] = None
-    tools: Optional[List[Dict[str, Any]]] = None
-    response_format: Optional[Dict[str, str]] = None
+    tools: Optional[list[dict[str, Any]]] = None
+    response_format: Optional[dict[str, str]] = None
 
     model_config = ConfigDict(
         # Avoid Pydantic's protected namespace warning since we want to use
