@@ -1,7 +1,7 @@
 from enum import Enum
 from http.client import HTTPException
 from json import loads
-from typing import Any, Callable, Dict, Optional, Union
+from typing import Any, Callable, Optional, Union
 from urllib.parse import urljoin
 
 from requests import Response
@@ -24,11 +24,11 @@ def make_request(
     request_method: Callable,
     base_url: str,
     endpoint: str,
-    body: Optional[Dict] = None,
-    data: Optional[Dict] = None,
-    files: Optional[Dict] = None,
-    params: Optional[Dict] = None,
-    headers: Optional[Dict[str, str]] = None,
+    body: Optional[dict] = None,
+    data: Optional[dict] = None,
+    files: Optional[dict] = None,
+    params: Optional[dict] = None,
+    headers: Optional[dict[str, str]] = None,
     timeout: Union[int, None] = None,
     stream: bool = False,
 ) -> Any:
@@ -75,13 +75,13 @@ class HttpHeaders(str, Enum):
     application_json = "application/json"
 
     @staticmethod
-    def accept_json() -> Dict[str, str]:
+    def accept_json() -> dict[str, str]:
         return {HttpHeaders.accept: HttpHeaders.application_json}
 
     @staticmethod
-    def content_type_json() -> Dict[str, str]:
+    def content_type_json() -> dict[str, str]:
         return {HttpHeaders.content_type: HttpHeaders.application_json}
 
     @staticmethod
-    def json() -> Dict[str, str]:
+    def json() -> dict[str, str]:
         return {**HttpHeaders.accept_json(), **HttpHeaders.content_type_json()}
